# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/traffic/v0/member_traffic_status.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/traffic/v0/member_traffic_status.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>com/digitalasset/canton/traffic/v0/member_traffic_status.proto\x12\"com.digitalasset.canton.traffic.v0\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xf1\x03\n\x13MemberTrafficStatus\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12W\n\x19total_extra_traffic_limit\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt64ValueR\x16totalExtraTrafficLimit\x12?\n\x1ctotal_extra_traffic_consumed\x18\x03 \x01(\x04R\x19totalExtraTrafficConsumed\x12\x66\n\rtop_up_events\x18\x04 \x03(\x0b\x32\x42.com.digitalasset.canton.traffic.v0.MemberTrafficStatus.TopUpEventR\x0btopUpEvents\x12*\n\x02ts\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x02ts\x1a\x93\x01\n\nTopUpEvent\x12=\n\x0c\x65\x66\x66\x65\x63tive_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x65\x66\x66\x65\x63tiveAt\x12\x16\n\x06serial\x18\x02 \x01(\rR\x06serial\x12.\n\x13\x65xtra_traffic_limit\x18\x03 \x01(\x04R\x11\x65xtraTrafficLimitBSZQgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/traffic/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.traffic.v0.member_traffic_status_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZQgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/traffic/v0'
  _globals['_MEMBERTRAFFICSTATUS']._serialized_start=168
  _globals['_MEMBERTRAFFICSTATUS']._serialized_end=665
  _globals['_MEMBERTRAFFICSTATUS_TOPUPEVENT']._serialized_start=518
  _globals['_MEMBERTRAFFICSTATUS_TOPUPEVENT']._serialized_end=665
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ..v0 import sequencer_initialization_snapshot_pb2 as _sequencer_initialization_snapshot_pb2
from ....protocol.v1 import sequencing_pb2 as _sequencing_pb2
from ....protocol.v0 import topology_ext_pb2 as _topology_ext_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class InitRequest(_message.Message):
    __slots__ = ("domain_id", "topology_snapshot", "domain_parameters", "snapshot")
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    TOPOLOGY_SNAPSHOT_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    SNAPSHOT_FIELD_NUMBER: _ClassVar[int]
    domain_id: str
    topology_snapshot: _topology_ext_pb2.TopologyTransactions
    domain_parameters: _sequencing_pb2.StaticDomainParameters
    snapshot: _sequencer_initialization_snapshot_pb2.SequencerSnapshot
    def __init__(self, domain_id: _Optional[str] = ..., topology_snapshot: _Optional[_Union[_topology_ext_pb2.TopologyTransactions, _Mapping]] = ..., domain_parameters: _Optional[_Union[_sequencing_pb2.StaticDomainParameters, _Mapping]] = ..., snapshot: _Optional[_Union[_sequencer_initialization_snapshot_pb2.SequencerSnapshot, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/topology/admin/v0/topology_manager_read_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/topology/admin/v0/topology_manager_read_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....crypto.v0 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v0_dot_crypto__pb2
from ....protocol.v0 import sequencing_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2
from ....protocol.v0 import topology_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_topology__pb2
from ....protocol.v1 import sequencing_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v1_dot_sequencing__pb2
from ....protocol.v2 import domain_params_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v2_dot_domain__params__pb2
from ....protocol.v0 import topology_ext_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_topology__ext__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMcom/digitalasset/canton/topology/admin/v0/topology_manager_read_service.proto\x12)com.digitalasset.canton.topology.admin.v0\x1a.com/digitalasset/canton/crypto/v0/crypto.proto\x1a\x34\x63om/digitalasset/canton/protocol/v0/sequencing.proto\x1a\x32\x63om/digitalasset/canton/protocol/v0/topology.proto\x1a\x34\x63om/digitalasset/canton/protocol/v1/sequencing.proto\x1a\x37\x63om/digitalasset/canton/protocol/v2/domain_params.proto\x1a\x36\x63om/digitalasset/canton/protocol/v0/topology_ext.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xa0\x01\n\x1eListNamespaceDelegationRequest\x12S\n\nbase_query\x18\x01 \x01(\x0b\x32\x34.com.digitalasset.canton.topology.admin.v0.BaseQueryR\tbaseQuery\x12)\n\x10\x66ilter_namespace\x18\x02 \x01(\tR\x0f\x66ilterNamespace\"\xea\x02\n\x1dListNamespaceDelegationResult\x12i\n\x07results\x18\x01 \x03(\x0b\x32O.com.digitalasset.canton.topology.admin.v0.ListNamespaceDelegationResult.ResultR\x07results\x1a\xdd\x01\n\x06Result\x12O\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v0.BaseResultR\x07\x63ontext\x12L\n\x04item\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v0.NamespaceDelegationR\x04item\x12\x34\n\x16target_key_fingerprint\x18\x03 \x01(\tR\x14targetKeyFingerprint\"\x95\x01\n\x1fListIdentifierDelegationRequest\x12S\n\nbase_query\x18\x01 \x01(\x0b\x32\x34.com.digitalasset.canton.topology.admin.v0.BaseQueryR\tbaseQuery\x12\x1d\n\nfilter_uid\x18\x02 \x01(\tR\tfilterUid\"\xed\x02\n\x1eListIdentifierDelegationResult\x12j\n\x07results\x18\x01 \x03(\x0b\x32P.com.digitalasset.canton.topology.admin.v0.ListIdentifierDelegationResult.ResultR\x07results\x1a\xde\x01\n\x06Result\x12O\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v0.BaseResultR\x07\x63ontext\x12M\n\x04item\x18\x02 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v0.IdentifierDelegationR\x04item\x12\x34\n\x16target_key_fingerprint\x18\x03 \x01(\tR\x14targetKeyFingerprint\"\x93\x05\n\tBaseQuery\x12!\n\x0c\x66ilter_store\x18\x01 \x01(\tR\x0b\x66ilterStore\x12&\n\x0fuse_state_store\x18\x02 \x01(\x08R\ruseStateStore\x12S\n\toperation\x18\x03 \x01(\x0e\x32\x35.com.digitalasset.canton.protocol.v0.TopologyChangeOpR\toperation\x12)\n\x10\x66ilter_operation\x18\x04 \x01(\x08R\x0f\x66ilterOperation\x12\x38\n\x08snapshot\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x08snapshot\x12\x37\n\nhead_state\x18\x06 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\theadState\x12V\n\x05range\x18\x07 \x01(\x0b\x32>.com.digitalasset.canton.topology.admin.v0.BaseQuery.TimeRangeH\x00R\x05range\x12*\n\x11\x66ilter_signed_key\x18\x08 \x01(\tR\x0f\x66ilterSignedKey\x12G\n\x10protocol_version\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0fprotocolVersion\x1am\n\tTimeRange\x12.\n\x04\x66rom\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x04\x66rom\x12\x30\n\x05until\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x05untilB\x0c\n\ntime_query\"\xfd\x02\n\nBaseResult\x12\x14\n\x05store\x18\x01 \x01(\tR\x05store\x12\x38\n\tsequenced\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tsequenced\x12\x39\n\nvalid_from\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tvalidFrom\x12;\n\x0bvalid_until\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nvalidUntil\x12S\n\toperation\x18\x04 \x01(\x0e\x32\x35.com.digitalasset.canton.protocol.v0.TopologyChangeOpR\toperation\x12\x1e\n\nserialized\x18\x05 \x01(\x0cR\nserialized\x12\x32\n\x15signed_by_fingerprint\x18\x06 \x01(\tR\x13signedByFingerprint\"\xb1\x02\n\x1cListPartyToParticipantResult\x12h\n\x07results\x18\x02 \x03(\x0b\x32N.com.digitalasset.canton.topology.admin.v0.ListPartyToParticipantResult.ResultR\x07results\x1a\xa6\x01\n\x06Result\x12O\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v0.BaseResultR\x07\x63ontext\x12K\n\x04item\x18\x02 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v0.PartyToParticipantR\x04item\"\x9f\x05\n\x1dListPartyToParticipantRequest\x12S\n\nbase_query\x18\x01 \x01(\x0b\x32\x34.com.digitalasset.canton.topology.admin.v0.BaseQueryR\tbaseQuery\x12!\n\x0c\x66ilter_party\x18\x02 \x01(\tR\x0b\x66ilterParty\x12-\n\x12\x66ilter_participant\x18\x03 \x01(\tR\x11\x66ilterParticipant\x12\x8a\x01\n\x13\x66ilter_request_side\x18\x04 \x01(\x0b\x32Z.com.digitalasset.canton.topology.admin.v0.ListPartyToParticipantRequest.FilterRequestSideR\x11\x66ilterRequestSide\x12\x86\x01\n\x11\x66ilter_permission\x18\x05 \x01(\x0b\x32Y.com.digitalasset.canton.topology.admin.v0.ListPartyToParticipantRequest.FilterPermissionR\x10\x66ilterPermission\x1a[\n\x11\x46ilterRequestSide\x12\x46\n\x05value\x18\x01 \x01(\x0e\x32\x30.com.digitalasset.canton.protocol.v0.RequestSideR\x05value\x1a\x64\n\x10\x46ilterPermission\x12P\n\x05value\x18\x01 \x01(\x0e\x32:.com.digitalasset.canton.protocol.v0.ParticipantPermissionR\x05value\"\xb9\x03\n\x1cListOwnerToKeyMappingRequest\x12S\n\nbase_query\x18\x01 \x01(\x0b\x32\x34.com.digitalasset.canton.topology.admin.v0.BaseQueryR\tbaseQuery\x12\x31\n\x15\x66ilter_key_owner_type\x18\x02 \x01(\tR\x12\x66ilterKeyOwnerType\x12/\n\x14\x66ilter_key_owner_uid\x18\x03 \x01(\tR\x11\x66ilterKeyOwnerUid\x12\x86\x01\n\x12\x66ilter_key_purpose\x18\x04 \x01(\x0b\x32X.com.digitalasset.canton.topology.admin.v0.ListOwnerToKeyMappingRequest.FilterKeyPurposeR\x10\x66ilterKeyPurpose\x1aW\n\x10\x46ilterKeyPurpose\x12\x43\n\x05value\x18\x01 \x01(\x0e\x32-.com.digitalasset.canton.crypto.v0.KeyPurposeR\x05value\"\xd7\x02\n\x1bListOwnerToKeyMappingResult\x12g\n\x07results\x18\x01 \x03(\x0b\x32M.com.digitalasset.canton.topology.admin.v0.ListOwnerToKeyMappingResult.ResultR\x07results\x1a\xce\x01\n\x06Result\x12O\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v0.BaseResultR\x07\x63ontext\x12J\n\x04item\x18\x02 \x01(\x0b\x32\x36.com.digitalasset.canton.protocol.v0.OwnerToKeyMappingR\x04item\x12\'\n\x0fkey_fingerprint\x18\x03 \x01(\tR\x0ekeyFingerprint\"\x99\x01\n#ListSignedLegalIdentityClaimRequest\x12S\n\nbase_query\x18\x01 \x01(\x0b\x32\x34.com.digitalasset.canton.topology.admin.v0.BaseQueryR\tbaseQuery\x12\x1d\n\nfilter_uid\x18\x02 \x01(\tR\tfilterUid\"\xc3\x02\n\"ListSignedLegalIdentityClaimResult\x12n\n\x07results\x18\x01 \x03(\x0b\x32T.com.digitalasset.canton.topology.admin.v0.ListSignedLegalIdentityClaimResult.ResultR\x07results\x1a\xac\x01\n\x06Result\x12O\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v0.BaseResultR\x07\x63ontext\x12Q\n\x04item\x18\x02 \x01(\x0b\x32=.com.digitalasset.canton.protocol.v0.SignedLegalIdentityClaimR\x04item\"\x9f\x01\n\x19ListVettedPackagesRequest\x12S\n\nbase_query\x18\x01 \x01(\x0b\x32\x34.com.digitalasset.canton.topology.admin.v0.BaseQueryR\tbaseQuery\x12-\n\x12\x66ilter_participant\x18\x02 \x01(\tR\x11\x66ilterParticipant\"\xa5\x02\n\x18ListVettedPackagesResult\x12\x64\n\x07results\x18\x01 \x03(\x0b\x32J.com.digitalasset.canton.topology.admin.v0.ListVettedPackagesResult.ResultR\x07results\x1a\xa2\x01\n\x06Result\x12O\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v0.BaseResultR\x07\x63ontext\x12G\n\x04item\x18\x02 \x01(\x0b\x32\x33.com.digitalasset.canton.protocol.v0.VettedPackagesR\x04item\"y\n\"ListDomainParametersChangesRequest\x12S\n\nbase_query\x18\x01 \x01(\x0b\x32\x34.com.digitalasset.canton.topology.admin.v0.BaseQueryR\tbaseQuery\"\xec\x03\n!ListDomainParametersChangesResult\x12m\n\x07results\x18\x01 \x03(\x0b\x32S.com.digitalasset.canton.topology.admin.v0.ListDomainParametersChangesResult.ResultR\x07results\x1a\xd7\x02\n\x06Result\x12O\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v0.BaseResultR\x07\x63ontext\x12N\n\x02v0\x18\x02 \x01(\x0b\x32<.com.digitalasset.canton.protocol.v0.DynamicDomainParametersH\x00R\x02v0\x12N\n\x02v1\x18\x03 \x01(\x0b\x32<.com.digitalasset.canton.protocol.v1.DynamicDomainParametersH\x00R\x02v1\x12N\n\x02v2\x18\x04 \x01(\x0b\x32<.com.digitalasset.canton.protocol.v2.DynamicDomainParametersH\x00R\x02v2B\x0c\n\nparameters\"\x1c\n\x1aListAvailableStoresRequest\"8\n\x19ListAvailableStoresResult\x12\x1b\n\tstore_ids\x18\x01 \x03(\tR\x08storeIds\"\xcc\x01\n!ListParticipantDomainStateRequest\x12S\n\nbase_query\x18\x01 \x01(\x0b\x32\x34.com.digitalasset.canton.topology.admin.v0.BaseQueryR\tbaseQuery\x12#\n\rfilter_domain\x18\x02 \x01(\tR\x0c\x66ilterDomain\x12-\n\x12\x66ilter_participant\x18\x03 \x01(\tR\x11\x66ilterParticipant\"\xb7\x02\n ListParticipantDomainStateResult\x12l\n\x07results\x18\x01 \x03(\x0b\x32R.com.digitalasset.canton.topology.admin.v0.ListParticipantDomainStateResult.ResultR\x07results\x1a\xa4\x01\n\x06Result\x12O\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v0.BaseResultR\x07\x63ontext\x12I\n\x04item\x18\x02 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v0.ParticipantStateR\x04item\"\xc3\x01\n\x1eListMediatorDomainStateRequest\x12S\n\nbase_query\x18\x01 \x01(\x0b\x32\x34.com.digitalasset.canton.topology.admin.v0.BaseQueryR\tbaseQuery\x12#\n\rfilter_domain\x18\x02 \x01(\tR\x0c\x66ilterDomain\x12\'\n\x0f\x66ilter_mediator\x18\x03 \x01(\tR\x0e\x66ilterMediator\"\xb4\x02\n\x1dListMediatorDomainStateResult\x12i\n\x07results\x18\x01 \x03(\x0b\x32O.com.digitalasset.canton.topology.admin.v0.ListMediatorDomainStateResult.ResultR\x07results\x1a\xa7\x01\n\x06Result\x12O\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v0.BaseResultR\x07\x63ontext\x12L\n\x04item\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v0.MediatorDomainStateR\x04item\"e\n\x0eListAllRequest\x12S\n\nbase_query\x18\x01 \x01(\x0b\x32\x34.com.digitalasset.canton.topology.admin.v0.BaseQueryR\tbaseQuery\"d\n\x0fListAllResponse\x12Q\n\x06result\x18\x01 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v0.TopologyTransactionsR\x06result2\x8c\x0f\n\x1aTopologyManagerReadService\x12\xa2\x01\n\x13ListAvailableStores\x12\x45.com.digitalasset.canton.topology.admin.v0.ListAvailableStoresRequest\x1a\x44.com.digitalasset.canton.topology.admin.v0.ListAvailableStoresResult\x12\xab\x01\n\x16ListPartyToParticipant\x12H.com.digitalasset.canton.topology.admin.v0.ListPartyToParticipantRequest\x1aG.com.digitalasset.canton.topology.admin.v0.ListPartyToParticipantResult\x12\xa8\x01\n\x15ListOwnerToKeyMapping\x12G.com.digitalasset.canton.topology.admin.v0.ListOwnerToKeyMappingRequest\x1a\x46.com.digitalasset.canton.topology.admin.v0.ListOwnerToKeyMappingResult\x12\xae\x01\n\x17ListNamespaceDelegation\x12I.com.digitalasset.canton.topology.admin.v0.ListNamespaceDelegationRequest\x1aH.com.digitalasset.canton.topology.admin.v0.ListNamespaceDelegationResult\x12\xb1\x01\n\x18ListIdentifierDelegation\x12J.com.digitalasset.canton.topology.admin.v0.ListIdentifierDelegationRequest\x1aI.com.digitalasset.canton.topology.admin.v0.ListIdentifierDelegationResult\x12\xbd\x01\n\x1cListSignedLegalIdentityClaim\x12N.com.digitalasset.canton.topology.admin.v0.ListSignedLegalIdentityClaimRequest\x1aM.com.digitalasset.canton.topology.admin.v0.ListSignedLegalIdentityClaimResult\x12\xb7\x01\n\x1aListParticipantDomainState\x12L.com.digitalasset.canton.topology.admin.v0.ListParticipantDomainStateRequest\x1aK.com.digitalasset.canton.topology.admin.v0.ListParticipantDomainStateResult\x12\xae\x01\n\x17ListMediatorDomainState\x12I.com.digitalasset.canton.topology.admin.v0.ListMediatorDomainStateRequest\x1aH.com.digitalasset.canton.topology.admin.v0.ListMediatorDomainStateResult\x12\x9f\x01\n\x12ListVettedPackages\x12\x44.com.digitalasset.canton.topology.admin.v0.ListVettedPackagesRequest\x1a\x43.com.digitalasset.canton.topology.admin.v0.ListVettedPackagesResult\x12\xba\x01\n\x1bListDomainParametersChanges\x12M.com.digitalasset.canton.topology.admin.v0.ListDomainParametersChangesRequest\x1aL.com.digitalasset.canton.topology.admin.v0.ListDomainParametersChangesResult\x12\x80\x01\n\x07ListAll\x12\x39.com.digitalasset.canton.topology.admin.v0.ListAllRequest\x1a:.com.digitalasset.canton.topology.admin.v0.ListAllResponseBZZXgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.topology.admin.v0.topology_manager_read_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZXgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v0'
  _globals['_LISTNAMESPACEDELEGATIONREQUEST']._serialized_start=540
  _globals['_LISTNAMESPACEDELEGATIONREQUEST']._serialized_end=700
  _globals['_LISTNAMESPACEDELEGATIONRESULT']._serialized_start=703
  _globals['_LISTNAMESPACEDELEGATIONRESULT']._serialized_end=1065
  _globals['_LISTNAMESPACEDELEGATIONRESULT_RESULT']._serialized_start=844
  _globals['_LISTNAMESPACEDELEGATIONRESULT_RESULT']._serialized_end=1065
  _globals['_LISTIDENTIFIERDELEGATIONREQUEST']._serialized_start=1068
  _globals['_LISTIDENTIFIERDELEGATIONREQUEST']._serialized_end=1217
  _globals['_LISTIDENTIFIERDELEGATIONRESULT']._serialized_start=1220
  _globals['_LISTIDENTIFIERDELEGATIONRESULT']._serialized_end=1585
  _globals['_LISTIDENTIFIERDELEGATIONRESULT_RESULT']._serialized_start=1363
  _globals['_LISTIDENTIFIERDELEGATIONRESULT_RESULT']._serialized_end=1585
  _globals['_BASEQUERY']._serialized_start=1588
  _globals['_BASEQUERY']._serialized_end=2247
  _globals['_BASEQUERY_TIMERANGE']._serialized_start=2124
  _globals['_BASEQUERY_TIMERANGE']._serialized_end=2233
  _globals['_BASERESULT']._serialized_start=2250
  _globals['_BASERESULT']._serialized_end=2631
  _globals['_LISTPARTYTOPARTICIPANTRESULT']._serialized_start=2634
  _globals['_LISTPARTYTOPARTICIPANTRESULT']._serialized_end=2939
  _globals['_LISTPARTYTOPARTICIPANTRESULT_RESULT']._serialized_start=2773
  _globals['_LISTPARTYTOPARTICIPANTRESULT_RESULT']._serialized_end=2939
  _globals['_LISTPARTYTOPARTICIPANTREQUEST']._serialized_start=2942
  _globals['_LISTPARTYTOPARTICIPANTREQUEST']._serialized_end=3613
  _globals['_LISTPARTYTOPARTICIPANTREQUEST_FILTERREQUESTSIDE']._serialized_start=3420
  _globals['_LISTPARTYTOPARTICIPANTREQUEST_FILTERREQUESTSIDE']._serialized_end=3511
  _globals['_LISTPARTYTOPARTICIPANTREQUEST_FILTERPERMISSION']._serialized_start=3513
  _globals['_LISTPARTYTOPARTICIPANTREQUEST_FILTERPERMISSION']._serialized_end=3613
  _globals['_LISTOWNERTOKEYMAPPINGREQUEST']._serialized_start=3616
  _globals['_LISTOWNERTOKEYMAPPINGREQUEST']._serialized_end=4057
  _globals['_LISTOWNERTOKEYMAPPINGREQUEST_FILTERKEYPURPOSE']._serialized_start=3970
  _globals['_LISTOWNERTOKEYMAPPINGREQUEST_FILTERKEYPURPOSE']._serialized_end=4057
  _globals['_LISTOWNERTOKEYMAPPINGRESULT']._serialized_start=4060
  _globals['_LISTOWNERTOKEYMAPPINGRESULT']._serialized_end=4403
  _globals['_LISTOWNERTOKEYMAPPINGRESULT_RESULT']._serialized_start=4197
  _globals['_LISTOWNERTOKEYMAPPINGRESULT_RESULT']._serialized_end=4403
  _globals['_LISTSIGNEDLEGALIDENTITYCLAIMREQUEST']._serialized_start=4406
  _globals['_LISTSIGNEDLEGALIDENTITYCLAIMREQUEST']._serialized_end=4559
  _globals['_LISTSIGNEDLEGALIDENTITYCLAIMRESULT']._serialized_start=4562
  _globals['_LISTSIGNEDLEGALIDENTITYCLAIMRESULT']._serialized_end=4885
  _globals['_LISTSIGNEDLEGALIDENTITYCLAIMRESULT_RESULT']._serialized_start=4713
  _globals['_LISTSIGNEDLEGALIDENTITYCLAIMRESULT_RESULT']._serialized_end=4885
  _globals['_LISTVETTEDPACKAGESREQUEST']._serialized_start=4888
  _globals['_LISTVETTEDPACKAGESREQUEST']._serialized_end=5047
  _globals['_LISTVETTEDPACKAGESRESULT']._serialized_start=5050
  _globals['_LISTVETTEDPACKAGESRESULT']._serialized_end=5343
  _globals['_LISTVETTEDPACKAGESRESULT_RESULT']._serialized_start=5181
  _globals['_LISTVETTEDPACKAGESRESULT_RESULT']._serialized_end=5343
  _globals['_LISTDOMAINPARAMETERSCHANGESREQUEST']._serialized_start=5345
  _globals['_LISTDOMAINPARAMETERSCHANGESREQUEST']._serialized_end=5466
  _globals['_LISTDOMAINPARAMETERSCHANGESRESULT']._serialized_start=5469
  _globals['_LISTDOMAINPARAMETERSCHANGESRESULT']._serialized_end=5961
  _globals['_LISTDOMAINPARAMETERSCHANGESRESULT_RESULT']._serialized_start=5618
  _globals['_LISTDOMAINPARAMETERSCHANGESRESULT_RESULT']._serialized_end=5961
  _globals['_LISTAVAILABLESTORESREQUEST']._serialized_start=5963
  _globals['_LISTAVAILABLESTORESREQUEST']._serialized_end=5991
  _globals['_LISTAVAILABLESTORESRESULT']._serialized_start=5993
  _globals['_LISTAVAILABLESTORESRESULT']._serialized_end=6049
  _globals['_LISTPARTICIPANTDOMAINSTATEREQUEST']._serialized_start=6052
  _globals['_LISTPARTICIPANTDOMAINSTATEREQUEST']._serialized_end=6256
  _globals['_LISTPARTICIPANTDOMAINSTATERESULT']._serialized_start=6259
  _globals['_LISTPARTICIPANTDOMAINSTATERESULT']._serialized_end=6570
  _globals['_LISTPARTICIPANTDOMAINSTATERESULT_RESULT']._serialized_start=6406
  _globals['_LISTPARTICIPANTDOMAINSTATERESULT_RESULT']._serialized_end=6570
  _globals['_LISTMEDIATORDOMAINSTATEREQUEST']._serialized_start=6573
  _globals['_LISTMEDIATORDOMAINSTATEREQUEST']._serialized_end=6768
  _globals['_LISTMEDIATORDOMAINSTATERESULT']._serialized_start=6771
  _globals['_LISTMEDIATORDOMAINSTATERESULT']._serialized_end=7079
  _globals['_LISTMEDIATORDOMAINSTATERESULT_RESULT']._serialized_start=6912
  _globals['_LISTMEDIATORDOMAINSTATERESULT_RESULT']._serialized_end=7079
  _globals['_LISTALLREQUEST']._serialized_start=7081
  _globals['_LISTALLREQUEST']._serialized_end=7182
  _globals['_LISTALLRESPONSE']._serialized_start=7184
  _globals['_LISTALLRESPONSE']._serialized_end=7284
  _globals['_TOPOLOGYMANAGERREADSERVICE']._serialized_start=7287
  _globals['_TOPOLOGYMANAGERREADSERVICE']._serialized_end=9219
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import completion_pb2 as _completion_pb2
from . import ledger_offset_pb2 as _ledger_offset_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CompletionStreamRequest(_message.Message):
    __slots__ = ("ledger_id", "application_id", "parties", "offset")
    LEDGER_ID_FIELD_NUMBER: _ClassVar[int]
    APPLICATION_ID_FIELD_NUMBER: _ClassVar[int]
    PARTIES_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    ledger_id: str
    application_id: str
    parties: _containers.RepeatedScalarFieldContainer[str]
    offset: _ledger_offset_pb2.LedgerOffset
    def __init__(self, ledger_id: _Optional[str] = ..., application_id: _Optional[str] = ..., parties: _Optional[_Iterable[str]] = ..., offset: _Optional[_Union[_ledger_offset_pb2.LedgerOffset, _Mapping]] = ...) -> None: ...

class CompletionStreamResponse(_message.Message):
    __slots__ = ("checkpoint", "completions")
    CHECKPOINT_FIELD_NUMBER: _ClassVar[int]
    COMPLETIONS_FIELD_NUMBER: _ClassVar[int]
    checkpoint: Checkpoint
    completions: _containers.RepeatedCompositeFieldContainer[_completion_pb2.Completion]
    def __init__(self, checkpoint: _Optional[_Union[Checkpoint, _Mapping]] = ..., completions: _Optional[_Iterable[_Union[_completion_pb2.Completion, _Mapping]]] = ...) -> None: ...

class Checkpoint(_message.Message):
    __slots__ = ("record_time", "offset")
    RECORD_TIME_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    record_time: _timestamp_pb2.Timestamp
    offset: _ledger_offset_pb2.LedgerOffset
    def __init__(self, record_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., offset: _Optional[_Union[_ledger_offset_pb2.LedgerOffset, _Mapping]] = ...) -> None: ...

class CompletionEndRequest(_message.Message):
    __slots__ = ("ledger_id",)
    LEDGER_ID_FIELD_NUMBER: _ClassVar[int]
    ledger_id: str
    def __init__(self, ledger_id: _Optional[str] = ...) -> None: ...

class CompletionEndResponse(_message.Message):
    __slots__ = ("offset",)
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    offset: _ledger_offset_pb2.LedgerOffset
    def __init__(self, offset: _Optional[_Union[_ledger_offset_pb2.LedgerOffset, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .sequencer_initialization_snapshot_pb2 import ImplementationSpecificInfo, SequencerMemberStatus, SequencerPruningStatus, SequencerSnapshot
from .sequencer_administration_service_pb2 import DisableMemberRequest, DisableMemberResponse, OnboardingStateForSequencer, OnboardingStateRequest, OnboardingStateResponse, PruningStatusRequest, PruningStatusResponse, SetTrafficPurchasedRequest, SetTrafficPurchasedResponse, SnapshotRequest, SnapshotResponse, TrafficControlStateRequest, TrafficControlStateResponse
from .sequencer_administration_service_pb2_grpc import SequencerAdministrationServiceStub
from .sequencer_bft_administration_service_pb2 import AddPeerEndpointRequest, AddPeerEndpointResponse, GetOrderingTopologyRequest, GetOrderingTopologyResponse, GetPeerNetworkStatusRequest, GetPeerNetworkStatusResponse, PeerEndpoint, PeerEndpointHealth, PeerEndpointHealthStatus, PeerEndpointStatus, RemovePeerEndpointRequest, RemovePeerEndpointResponse
from .sequencer_bft_administration_service_pb2_grpc import SequencerBftAdministrationServiceStub
from .sequencer_initialization_service_pb2 import InitializeSequencerFromGenesisStateRequest, InitializeSequencerFromGenesisStateResponse, InitializeSequencerFromOnboardingStateRequest, InitializeSequencerFromOnboardingStateResponse
from .sequencer_initialization_service_pb2_grpc import SequencerInitializationServiceStub
from .sequencer_pruning_administration_service_pb2 import SequencerPruning
from .sequencer_pruning_administration_service_pb2_grpc import SequencerPruningAdministrationServiceStub
from .sequencer_version_service_pb2 import SequencerVersion
from .sequencer_version_service_pb2_grpc import SequencerVersionServiceStub

__all__ = [
    "AddPeerEndpointRequest",
    "AddPeerEndpointResponse",
    "DisableMemberRequest",
    "DisableMemberResponse",
    "GetOrderingTopologyRequest",
    "GetOrderingTopologyResponse",
    "GetPeerNetworkStatusRequest",
    "GetPeerNetworkStatusResponse",
    "ImplementationSpecificInfo",
    "InitializeSequencerFromGenesisStateRequest",
    "InitializeSequencerFromGenesisStateResponse",
    "InitializeSequencerFromOnboardingStateRequest",
    "InitializeSequencerFromOnboardingStateResponse",
    "OnboardingStateForSequencer",
    "OnboardingStateRequest",
    "OnboardingStateResponse",
    "PeerEndpoint",
    "PeerEndpointHealth",
    "PeerEndpointHealthStatus",
    "PeerEndpointStatus",
    "PruningStatusRequest",
    "PruningStatusResponse",
    "RemovePeerEndpointRequest",
    "RemovePeerEndpointResponse",
    "SequencerAdministrationServiceStub",
    "SequencerBftAdministrationServiceStub",
    "SequencerInitializationServiceStub",
    "SequencerMemberStatus",
    "SequencerPruning",
    "SequencerPruningAdministrationServiceStub",
    "SequencerPruningStatus",
    "SequencerSnapshot",
    "SequencerVersion",
    "SequencerVersionServiceStub",
    "SetTrafficPurchasedRequest",
    "SetTrafficPurchasedResponse",
    "SnapshotRequest",
    "SnapshotResponse",
    "TrafficControlStateRequest",
    "TrafficControlStateResponse",
]



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ....protocol.v0 import participant_transaction_pb2 as _participant_transaction_pb2
from ....protocol.v0 import participant_transfer_pb2 as _participant_transfer_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CommandKind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    Transaction: _ClassVar[CommandKind]
    TransferOut: _ClassVar[CommandKind]
    TransferIn: _ClassVar[CommandKind]
Transaction: CommandKind
TransferOut: CommandKind
TransferIn: CommandKind

class LedgerSyncEvent(_message.Message):
    __slots__ = ("configuration_changed", "configuration_change_rejected", "party_added_to_participant", "public_package_upload", "transaction_accepted", "command_rejected", "party_allocation_rejected", "public_package_upload_rejected", "transferred_out", "transferred_in", "contracts_added", "contracts_purged")
    CONFIGURATION_CHANGED_FIELD_NUMBER: _ClassVar[int]
    CONFIGURATION_CHANGE_REJECTED_FIELD_NUMBER: _ClassVar[int]
    PARTY_ADDED_TO_PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_PACKAGE_UPLOAD_FIELD_NUMBER: _ClassVar[int]
    TRANSACTION_ACCEPTED_FIELD_NUMBER: _ClassVar[int]
    COMMAND_REJECTED_FIELD_NUMBER: _ClassVar[int]
    PARTY_ALLOCATION_REJECTED_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_PACKAGE_UPLOAD_REJECTED_FIELD_NUMBER: _ClassVar[int]
    TRANSFERRED_OUT_FIELD_NUMBER: _ClassVar[int]
    TRANSFERRED_IN_FIELD_NUMBER: _ClassVar[int]
    CONTRACTS_ADDED_FIELD_NUMBER: _ClassVar[int]
    CONTRACTS_PURGED_FIELD_NUMBER: _ClassVar[int]
    configuration_changed: ConfigurationChanged
    configuration_change_rejected: ConfigurationChangeRejected
    party_added_to_participant: PartyAddedToParticipant
    public_package_upload: PublicPackageUpload
    transaction_accepted: TransactionAccepted
    command_rejected: CommandRejected
    party_allocation_rejected: PartyAllocationRejected
    public_package_upload_rejected: PublicPackageUploadRejected
    transferred_out: TransferredOut
    transferred_in: TransferredIn
    contracts_added: ContractsAdded
    contracts_purged: ContractsPurged
    def __init__(self, configuration_changed: _Optional[_Union[ConfigurationChanged, _Mapping]] = ..., configuration_change_rejected: _Optional[_Union[ConfigurationChangeRejected, _Mapping]] = ..., party_added_to_participant: _Optional[_Union[PartyAddedToParticipant, _Mapping]] = ..., public_package_upload: _Optional[_Union[PublicPackageUpload, _Mapping]] = ..., transaction_accepted: _Optional[_Union[TransactionAccepted, _Mapping]] = ..., command_rejected: _Optional[_Union[CommandRejected, _Mapping]] = ..., party_allocation_rejected: _Optional[_Union[PartyAllocationRejected, _Mapping]] = ..., public_package_upload_rejected: _Optional[_Union[PublicPackageUploadRejected, _Mapping]] = ..., transferred_out: _Optional[_Union[TransferredOut, _Mapping]] = ..., transferred_in: _Optional[_Union[TransferredIn, _Mapping]] = ..., contracts_added: _Optional[_Union[ContractsAdded, _Mapping]] = ..., contracts_purged: _Optional[_Union[ContractsPurged, _Mapping]] = ...) -> None: ...

class ConfigurationChanged(_message.Message):
    __slots__ = ("submission_id", "configuration", "participant_id", "record_time")
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    RECORD_TIME_FIELD_NUMBER: _ClassVar[int]
    submission_id: str
    configuration: Configuration
    participant_id: str
    record_time: _timestamp_pb2.Timestamp
    def __init__(self, submission_id: _Optional[str] = ..., configuration: _Optional[_Union[Configuration, _Mapping]] = ..., participant_id: _Optional[str] = ..., record_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class Configuration(_message.Message):
    __slots__ = ("generation", "time_model", "max_deduplication_duration")
    GENERATION_FIELD_NUMBER: _ClassVar[int]
    TIME_MODEL_FIELD_NUMBER: _ClassVar[int]
    MAX_DEDUPLICATION_DURATION_FIELD_NUMBER: _ClassVar[int]
    generation: int
    time_model: TimeModel
    max_deduplication_duration: _duration_pb2.Duration
    def __init__(self, generation: _Optional[int] = ..., time_model: _Optional[_Union[TimeModel, _Mapping]] = ..., max_deduplication_duration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...

class TimeModel(_message.Message):
    __slots__ = ("avg_transaction_latency", "min_skew", "max_skew")
    AVG_TRANSACTION_LATENCY_FIELD_NUMBER: _ClassVar[int]
    MIN_SKEW_FIELD_NUMBER: _ClassVar[int]
    MAX_SKEW_FIELD_NUMBER: _ClassVar[int]
    avg_transaction_latency: _duration_pb2.Duration
    min_skew: _duration_pb2.Duration
    max_skew: _duration_pb2.Duration
    def __init__(self, avg_transaction_latency: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., min_skew: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., max_skew: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...

class ConfigurationChangeRejected(_message.Message):
    __slots__ = ("submission_id", "reason", "participant_id", "recordTime", "proposed_configuration")
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    RECORDTIME_FIELD_NUMBER: _ClassVar[int]
    PROPOSED_CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    submission_id: str
    reason: str
    participant_id: str
    recordTime: _timestamp_pb2.Timestamp
    proposed_configuration: Configuration
    def __init__(self, submission_id: _Optional[str] = ..., reason: _Optional[str] = ..., participant_id: _Optional[str] = ..., recordTime: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., proposed_configuration: _Optional[_Union[Configuration, _Mapping]] = ...) -> None: ...

class PartyAddedToParticipant(_message.Message):
    __slots__ = ("party", "display_name", "participant_id", "record_time", "submission_id")
    PARTY_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    RECORD_TIME_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    party: str
    display_name: str
    participant_id: str
    record_time: _timestamp_pb2.Timestamp
    submission_id: str
    def __init__(self, party: _Optional[str] = ..., display_name: _Optional[str] = ..., participant_id: _Optional[str] = ..., record_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., submission_id: _Optional[str] = ...) -> None: ...

class PartyAllocationRejected(_message.Message):
    __slots__ = ("submission_id", "participant_id", "record_time", "rejection_reason")
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    RECORD_TIME_FIELD_NUMBER: _ClassVar[int]
    REJECTION_REASON_FIELD_NUMBER: _ClassVar[int]
    submission_id: str
    participant_id: str
    record_time: _timestamp_pb2.Timestamp
    rejection_reason: str
    def __init__(self, submission_id: _Optional[str] = ..., participant_id: _Optional[str] = ..., record_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., rejection_reason: _Optional[str] = ...) -> None: ...

class PublicPackageUpload(_message.Message):
    __slots__ = ("archives", "source_description", "record_time", "submission_id")
    ARCHIVES_FIELD_NUMBER: _ClassVar[int]
    SOURCE_DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    RECORD_TIME_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    archives: _containers.RepeatedScalarFieldContainer[bytes]
    source_description: _wrappers_pb2.StringValue
    record_time: _timestamp_pb2.Timestamp
    submission_id: str
    def __init__(self, archives: _Optional[_Iterable[bytes]] = ..., source_description: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., record_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., submission_id: _Optional[str] = ...) -> None: ...

class PublicPackageUploadRejected(_message.Message):
    __slots__ = ("submission_id", "record_time", "rejection_reason")
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    RECORD_TIME_FIELD_NUMBER: _ClassVar[int]
    REJECTION_REASON_FIELD_NUMBER: _ClassVar[int]
    submission_id: str
    record_time: _timestamp_pb2.Timestamp
    rejection_reason: str
    def __init__(self, submission_id: _Optional[str] = ..., record_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., rejection_reason: _Optional[str] = ...) -> None: ...

class TransactionAccepted(_message.Message):
    __slots__ = ("completion_info", "transaction_meta", "transaction", "transaction_id", "record_time", "divulged_contracts", "blinding_info", "contract_metadata", "hosted_witnesses")
    class ContractMetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: bytes
        def __init__(self, key: _Optional[str] = ..., value: _Optional[bytes] = ...) -> None: ...
    COMPLETION_INFO_FIELD_NUMBER: _ClassVar[int]
    TRANSACTION_META_FIELD_NUMBER: _ClassVar[int]
    TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    TRANSACTION_ID_FIELD_NUMBER: _ClassVar[int]
    RECORD_TIME_FIELD_NUMBER: _ClassVar[int]
    DIVULGED_CONTRACTS_FIELD_NUMBER: _ClassVar[int]
    BLINDING_INFO_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_METADATA_FIELD_NUMBER: _ClassVar[int]
    HOSTED_WITNESSES_FIELD_NUMBER: _ClassVar[int]
    completion_info: CompletionInfo
    transaction_meta: TransactionMeta
    transaction: bytes
    transaction_id: str
    record_time: _timestamp_pb2.Timestamp
    divulged_contracts: _containers.RepeatedCompositeFieldContainer[DivulgedContract]
    blinding_info: BlindingInfo
    contract_metadata: _containers.ScalarMap[str, bytes]
    hosted_witnesses: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, completion_info: _Optional[_Union[CompletionInfo, _Mapping]] = ..., transaction_meta: _Optional[_Union[TransactionMeta, _Mapping]] = ..., transaction: _Optional[bytes] = ..., transaction_id: _Optional[str] = ..., record_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., divulged_contracts: _Optional[_Iterable[_Union[DivulgedContract, _Mapping]]] = ..., blinding_info: _Optional[_Union[BlindingInfo, _Mapping]] = ..., contract_metadata: _Optional[_Mapping[str, bytes]] = ..., hosted_witnesses: _Optional[_Iterable[str]] = ...) -> None: ...

class CompletionInfo(_message.Message):
    __slots__ = ("act_as", "application_id", "command_id", "optDeduplicationPeriod", "submission_id")
    ACT_AS_FIELD_NUMBER: _ClassVar[int]
    APPLICATION_ID_FIELD_NUMBER: _ClassVar[int]
    COMMAND_ID_FIELD_NUMBER: _ClassVar[int]
    OPTDEDUPLICATIONPERIOD_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    act_as: _containers.RepeatedScalarFieldContainer[str]
    application_id: str
    command_id: str
    optDeduplicationPeriod: _participant_transaction_pb2.DeduplicationPeriod
    submission_id: str
    def __init__(self, act_as: _Optional[_Iterable[str]] = ..., application_id: _Optional[str] = ..., command_id: _Optional[str] = ..., optDeduplicationPeriod: _Optional[_Union[_participant_transaction_pb2.DeduplicationPeriod, _Mapping]] = ..., submission_id: _Optional[str] = ...) -> None: ...

class TransactionMeta(_message.Message):
    __slots__ = ("ledger_time", "workflow_id", "submission_time", "submission_seed", "used_packages", "node_seeds", "by_key_nodes", "domain_id")
    class ByKeyNodes(_message.Message):
        __slots__ = ("by_key_node",)
        BY_KEY_NODE_FIELD_NUMBER: _ClassVar[int]
        by_key_node: _containers.RepeatedScalarFieldContainer[int]
        def __init__(self, by_key_node: _Optional[_Iterable[int]] = ...) -> None: ...
    LEDGER_TIME_FIELD_NUMBER: _ClassVar[int]
    WORKFLOW_ID_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_TIME_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_SEED_FIELD_NUMBER: _ClassVar[int]
    USED_PACKAGES_FIELD_NUMBER: _ClassVar[int]
    NODE_SEEDS_FIELD_NUMBER: _ClassVar[int]
    BY_KEY_NODES_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    ledger_time: _timestamp_pb2.Timestamp
    workflow_id: _wrappers_pb2.StringValue
    submission_time: _timestamp_pb2.Timestamp
    submission_seed: bytes
    used_packages: _containers.RepeatedScalarFieldContainer[str]
    node_seeds: _containers.RepeatedCompositeFieldContainer[NodeSeed]
    by_key_nodes: TransactionMeta.ByKeyNodes
    domain_id: _wrappers_pb2.StringValue
    def __init__(self, ledger_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., workflow_id: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., submission_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., submission_seed: _Optional[bytes] = ..., used_packages: _Optional[_Iterable[str]] = ..., node_seeds: _Optional[_Iterable[_Union[NodeSeed, _Mapping]]] = ..., by_key_nodes: _Optional[_Union[TransactionMeta.ByKeyNodes, _Mapping]] = ..., domain_id: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...

class NodeSeed(_message.Message):
    __slots__ = ("node_index", "node_seed")
    NODE_INDEX_FIELD_NUMBER: _ClassVar[int]
    NODE_SEED_FIELD_NUMBER: _ClassVar[int]
    node_index: int
    node_seed: bytes
    def __init__(self, node_index: _Optional[int] = ..., node_seed: _Optional[bytes] = ...) -> None: ...

class DivulgedContract(_message.Message):
    __slots__ = ("contract_id", "contract_inst")
    CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_INST_FIELD_NUMBER: _ClassVar[int]
    contract_id: str
    contract_inst: bytes
    def __init__(self, contract_id: _Optional[str] = ..., contract_inst: _Optional[bytes] = ...) -> None: ...

class BlindingInfo(_message.Message):
    __slots__ = ("disclosure", "divulgence")
    class DisclosureEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: int
        value: Parties
        def __init__(self, key: _Optional[int] = ..., value: _Optional[_Union[Parties, _Mapping]] = ...) -> None: ...
    class DivulgenceEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: Parties
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[Parties, _Mapping]] = ...) -> None: ...
    DISCLOSURE_FIELD_NUMBER: _ClassVar[int]
    DIVULGENCE_FIELD_NUMBER: _ClassVar[int]
    disclosure: _containers.MessageMap[int, Parties]
    divulgence: _containers.MessageMap[str, Parties]
    def __init__(self, disclosure: _Optional[_Mapping[int, Parties]] = ..., divulgence: _Optional[_Mapping[str, Parties]] = ...) -> None: ...

class Parties(_message.Message):
    __slots__ = ("parties",)
    PARTIES_FIELD_NUMBER: _ClassVar[int]
    parties: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, parties: _Optional[_Iterable[str]] = ...) -> None: ...

class CommandRejected(_message.Message):
    __slots__ = ("completion_info", "record_time", "rejection_reason", "command_kind", "domain_id")
    class GrpcRejectionReasonTemplate(_message.Message):
        __slots__ = ("status",)
        STATUS_FIELD_NUMBER: _ClassVar[int]
        status: bytes
        def __init__(self, status: _Optional[bytes] = ...) -> None: ...
    COMPLETION_INFO_FIELD_NUMBER: _ClassVar[int]
    RECORD_TIME_FIELD_NUMBER: _ClassVar[int]
    REJECTION_REASON_FIELD_NUMBER: _ClassVar[int]
    COMMAND_KIND_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    completion_info: CompletionInfo
    record_time: _timestamp_pb2.Timestamp
    rejection_reason: CommandRejected.GrpcRejectionReasonTemplate
    command_kind: CommandKind
    domain_id: _wrappers_pb2.StringValue
    def __init__(self, completion_info: _Optional[_Union[CompletionInfo, _Mapping]] = ..., record_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., rejection_reason: _Optional[_Union[CommandRejected.GrpcRejectionReasonTemplate, _Mapping]] = ..., command_kind: _Optional[_Union[CommandKind, str]] = ..., domain_id: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...

class TransferredOut(_message.Message):
    __slots__ = ("update_id", "completion_info", "submitter", "record_time", "contract_id", "contract_stakeholders", "source_domain", "target_domain", "transfer_in_exclusivity", "workflow_id", "template_id", "is_transferring_participant", "hosted_stakeholders", "transfer_counter")
    UPDATE_ID_FIELD_NUMBER: _ClassVar[int]
    COMPLETION_INFO_FIELD_NUMBER: _ClassVar[int]
    SUBMITTER_FIELD_NUMBER: _ClassVar[int]
    RECORD_TIME_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_STAKEHOLDERS_FIELD_NUMBER: _ClassVar[int]
    SOURCE_DOMAIN_FIELD_NUMBER: _ClassVar[int]
    TARGET_DOMAIN_FIELD_NUMBER: _ClassVar[int]
    TRANSFER_IN_EXCLUSIVITY_FIELD_NUMBER: _ClassVar[int]
    WORKFLOW_ID_FIELD_NUMBER: _ClassVar[int]
    TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    IS_TRANSFERRING_PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    HOSTED_STAKEHOLDERS_FIELD_NUMBER: _ClassVar[int]
    TRANSFER_COUNTER_FIELD_NUMBER: _ClassVar[int]
    update_id: str
    completion_info: CompletionInfo
    submitter: str
    record_time: _timestamp_pb2.Timestamp
    contract_id: str
    contract_stakeholders: _containers.RepeatedScalarFieldContainer[str]
    source_domain: str
    target_domain: str
    transfer_in_exclusivity: _timestamp_pb2.Timestamp
    workflow_id: str
    template_id: str
    is_transferring_participant: bool
    hosted_stakeholders: _containers.RepeatedScalarFieldContainer[str]
    transfer_counter: int
    def __init__(self, update_id: _Optional[str] = ..., completion_info: _Optional[_Union[CompletionInfo, _Mapping]] = ..., submitter: _Optional[str] = ..., record_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., contract_id: _Optional[str] = ..., contract_stakeholders: _Optional[_Iterable[str]] = ..., source_domain: _Optional[str] = ..., target_domain: _Optional[str] = ..., transfer_in_exclusivity: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., workflow_id: _Optional[str] = ..., template_id: _Optional[str] = ..., is_transferring_participant: bool = ..., hosted_stakeholders: _Optional[_Iterable[str]] = ..., transfer_counter: _Optional[int] = ...) -> None: ...

class TransferredIn(_message.Message):
    __slots__ = ("update_id", "completion_info", "submitter", "record_time", "ledger_create_time", "create_node", "creating_transaction_id", "contract_metadata", "transfer_out_id", "target_domain", "create_transaction_accepted", "workflow_id", "is_transferring_participant", "hosted_stakeholders", "transfer_counter")
    UPDATE_ID_FIELD_NUMBER: _ClassVar[int]
    COMPLETION_INFO_FIELD_NUMBER: _ClassVar[int]
    SUBMITTER_FIELD_NUMBER: _ClassVar[int]
    RECORD_TIME_FIELD_NUMBER: _ClassVar[int]
    LEDGER_CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    CREATE_NODE_FIELD_NUMBER: _ClassVar[int]
    CREATING_TRANSACTION_ID_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_METADATA_FIELD_NUMBER: _ClassVar[int]
    TRANSFER_OUT_ID_FIELD_NUMBER: _ClassVar[int]
    TARGET_DOMAIN_FIELD_NUMBER: _ClassVar[int]
    CREATE_TRANSACTION_ACCEPTED_FIELD_NUMBER: _ClassVar[int]
    WORKFLOW_ID_FIELD_NUMBER: _ClassVar[int]
    IS_TRANSFERRING_PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    HOSTED_STAKEHOLDERS_FIELD_NUMBER: _ClassVar[int]
    TRANSFER_COUNTER_FIELD_NUMBER: _ClassVar[int]
    update_id: str
    completion_info: CompletionInfo
    submitter: str
    record_time: _timestamp_pb2.Timestamp
    ledger_create_time: _timestamp_pb2.Timestamp
    create_node: bytes
    creating_transaction_id: str
    contract_metadata: bytes
    transfer_out_id: _participant_transfer_pb2.TransferId
    target_domain: str
    create_transaction_accepted: bool
    workflow_id: str
    is_transferring_participant: bool
    hosted_stakeholders: _containers.RepeatedScalarFieldContainer[str]
    transfer_counter: int
    def __init__(self, update_id: _Optional[str] = ..., completion_info: _Optional[_Union[CompletionInfo, _Mapping]] = ..., submitter: _Optional[str] = ..., record_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., ledger_create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., create_node: _Optional[bytes] = ..., creating_transaction_id: _Optional[str] = ..., contract_metadata: _Optional[bytes] = ..., transfer_out_id: _Optional[_Union[_participant_transfer_pb2.TransferId, _Mapping]] = ..., target_domain: _Optional[str] = ..., create_transaction_accepted: bool = ..., workflow_id: _Optional[str] = ..., is_transferring_participant: bool = ..., hosted_stakeholders: _Optional[_Iterable[str]] = ..., transfer_counter: _Optional[int] = ...) -> None: ...

class ContractsAdded(_message.Message):
    __slots__ = ("transaction_id", "contracts", "domain_id", "ledger_time", "record_time", "hosted_witnesses", "contract_metadata", "workflow_id")
    class ContractMetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: bytes
        def __init__(self, key: _Optional[str] = ..., value: _Optional[bytes] = ...) -> None: ...
    TRANSACTION_ID_FIELD_NUMBER: _ClassVar[int]
    CONTRACTS_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    LEDGER_TIME_FIELD_NUMBER: _ClassVar[int]
    RECORD_TIME_FIELD_NUMBER: _ClassVar[int]
    HOSTED_WITNESSES_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_METADATA_FIELD_NUMBER: _ClassVar[int]
    WORKFLOW_ID_FIELD_NUMBER: _ClassVar[int]
    transaction_id: str
    contracts: _containers.RepeatedScalarFieldContainer[bytes]
    domain_id: str
    ledger_time: _timestamp_pb2.Timestamp
    record_time: _timestamp_pb2.Timestamp
    hosted_witnesses: _containers.RepeatedScalarFieldContainer[str]
    contract_metadata: _containers.ScalarMap[str, bytes]
    workflow_id: str
    def __init__(self, transaction_id: _Optional[str] = ..., contracts: _Optional[_Iterable[bytes]] = ..., domain_id: _Optional[str] = ..., ledger_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., record_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., hosted_witnesses: _Optional[_Iterable[str]] = ..., contract_metadata: _Optional[_Mapping[str, bytes]] = ..., workflow_id: _Optional[str] = ...) -> None: ...

class ContractsPurged(_message.Message):
    __slots__ = ("transaction_id", "contracts", "domain_id", "record_time", "hosted_witnesses")
    TRANSACTION_ID_FIELD_NUMBER: _ClassVar[int]
    CONTRACTS_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    RECORD_TIME_FIELD_NUMBER: _ClassVar[int]
    HOSTED_WITNESSES_FIELD_NUMBER: _ClassVar[int]
    transaction_id: str
    contracts: _containers.RepeatedScalarFieldContainer[bytes]
    domain_id: str
    record_time: _timestamp_pb2.Timestamp
    hosted_witnesses: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, transaction_id: _Optional[str] = ..., contracts: _Optional[_Iterable[bytes]] = ..., domain_id: _Optional[str] = ..., record_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., hosted_witnesses: _Optional[_Iterable[str]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .topology_manager_write_service_pb2 import AddTransactionsRequest, AddTransactionsResponse, AuthorizeRequest, AuthorizeResponse, GenerateTransactionsRequest, GenerateTransactionsResponse, ImportTopologySnapshotRequest, ImportTopologySnapshotResponse, SignTransactionsRequest, SignTransactionsResponse

__all__ = [
    "TopologyManagerWriteServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class TopologyManagerWriteServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _TopologyManagerWriteServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _TopologyManagerWriteServiceAsyncStub: ...  # type: ignore
    def Authorize(self, __1: AuthorizeRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[AuthorizeResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, AuthorizeResponse]]: ...
    def AddTransactions(self, __1: AddTransactionsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[AddTransactionsResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, AddTransactionsResponse]]: ...
    def ImportTopologySnapshot(self, __1: ImportTopologySnapshotRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ImportTopologySnapshotResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ImportTopologySnapshotResponse]]: ...
    def SignTransactions(self, __1: SignTransactionsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SignTransactionsResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, SignTransactionsResponse]]: ...
    def GenerateTransactions(self, __1: GenerateTransactionsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GenerateTransactionsResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, GenerateTransactionsResponse]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _TopologyManagerWriteServiceBlockingStub(TopologyManagerWriteServiceStub):
    def Authorize(self, __1: AuthorizeRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> AuthorizeResponse: ...
    def AddTransactions(self, __1: AddTransactionsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> AddTransactionsResponse: ...
    def ImportTopologySnapshot(self, __1: ImportTopologySnapshotRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ImportTopologySnapshotResponse: ...
    def SignTransactions(self, __1: SignTransactionsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SignTransactionsResponse: ...
    def GenerateTransactions(self, __1: GenerateTransactionsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GenerateTransactionsResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _TopologyManagerWriteServiceAsyncStub(TopologyManagerWriteServiceStub):
    def Authorize(self, __1: AuthorizeRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, AuthorizeResponse]: ...  # type: ignore
    def AddTransactions(self, __1: AddTransactionsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, AddTransactionsResponse]: ...  # type: ignore
    def ImportTopologySnapshot(self, __1: ImportTopologySnapshotRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ImportTopologySnapshotResponse]: ...  # type: ignore
    def SignTransactions(self, __1: SignTransactionsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SignTransactionsResponse]: ...  # type: ignore
    def GenerateTransactions(self, __1: GenerateTransactionsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GenerateTransactionsResponse]: ...  # type: ignore



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/domain/api/v0/sequencer_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/domain/api/v0/sequencer_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....protocol.v0 import sequencing_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2
from ....v0 import trace_context_pb2 as com_dot_digitalasset_dot_canton_dot_v0_dot_trace__context__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=com/digitalasset/canton/domain/api/v0/sequencer_service.proto\x12%com.digitalasset.canton.domain.api.v0\x1a\x34\x63om/digitalasset/canton/protocol/v0/sequencing.proto\x1a.com/digitalasset/canton/v0/trace_context.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"W\n\x19SendAsyncVersionedRequest\x12:\n\x19signed_submission_request\x18\x01 \x01(\x0cR\x17signedSubmissionRequest\"Y\n(SendAsyncUnauthenticatedVersionedRequest\x12-\n\x12submission_request\x18\x01 \x01(\x0cR\x11submissionRequest\"\x9a\x03\n\x11SendAsyncResponse\x12T\n\x05\x65rror\x18\x01 \x01(\x0b\x32>.com.digitalasset.canton.domain.api.v0.SendAsyncResponse.ErrorR\x05\x65rror\x1a\xae\x02\n\x05\x45rror\x12)\n\x0frequest_invalid\x18\x01 \x01(\tH\x00R\x0erequestInvalid\x12)\n\x0frequest_refused\x18\x02 \x01(\tH\x00R\x0erequestRefused\x12 \n\noverloaded\x18\x03 \x01(\tH\x00R\noverloaded\x12\'\n\x0esender_unknown\x18\x04 \x01(\tH\x00R\rsenderUnknown\x12%\n\rshutting_down\x18\x05 \x01(\tH\x00R\x0cshuttingDown\x12\"\n\x0bunavailable\x18\x06 \x01(\tH\x00R\x0bunavailable\x12/\n\x12unknown_recipients\x18\x07 \x01(\tH\x00R\x11unknownRecipientsB\x08\n\x06reason\"\xe0\x03\n\x17SendAsyncSignedResponse\x12Z\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x44.com.digitalasset.canton.domain.api.v0.SendAsyncSignedResponse.ErrorR\x05\x65rror\x1a\xe8\x02\n\x05\x45rror\x12)\n\x0frequest_invalid\x18\x01 \x01(\tH\x00R\x0erequestInvalid\x12)\n\x0frequest_refused\x18\x02 \x01(\tH\x00R\x0erequestRefused\x12 \n\noverloaded\x18\x03 \x01(\tH\x00R\noverloaded\x12\'\n\x0esender_unknown\x18\x04 \x01(\tH\x00R\rsenderUnknown\x12%\n\rshutting_down\x18\x05 \x01(\tH\x00R\x0cshuttingDown\x12\"\n\x0bunavailable\x18\x06 \x01(\tH\x00R\x0bunavailable\x12/\n\x12unknown_recipients\x18\x07 \x01(\tH\x00R\x11unknownRecipients\x12\x1c\n\x08internal\x18\x08 \x01(\tH\x00R\x08internal\x12\x1a\n\x07generic\x18\t \x01(\tH\x00R\x07genericB\x08\n\x06reason\"G\n\x13SubscriptionRequest\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12\x18\n\x07\x63ounter\x18\x02 \x01(\x03R\x07\x63ounter\"\xcf\x01\n\x14SubscriptionResponse\x12h\n\x16signed_sequenced_event\x18\x01 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v0.SignedContentR\x14signedSequencedEvent\x12M\n\rtrace_context\x18\x02 \x01(\x0b\x32(.com.digitalasset.canton.v0.TraceContextR\x0ctraceContext\"\x8c\x02\n\x1dVersionedSubscriptionResponse\x12\x34\n\x16signed_sequenced_event\x18\x01 \x01(\x0cR\x14signedSequencedEvent\x12M\n\rtrace_context\x18\x02 \x01(\x0b\x32(.com.digitalasset.canton.v0.TraceContextR\x0ctraceContext\x12\x66\n\rtraffic_state\x18\x03 \x01(\x0b\x32\x41.com.digitalasset.canton.domain.api.v0.SequencedEventTrafficStateR\x0ctrafficState\"f\n\x12\x41\x63knowledgeRequest\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\"\x8a\x01\n\x1aSequencedEventTrafficState\x12\x36\n\x17\x65xtra_traffic_remainder\x18\x02 \x01(\x04R\x15\x65xtraTrafficRemainder\x12\x34\n\x16\x65xtra_traffic_consumed\x18\x03 \x01(\x04R\x14\x65xtraTrafficConsumed2\x9b\x0c\n\x10SequencerService\x12}\n\tSendAsync\x12\x36.com.digitalasset.canton.protocol.v0.SubmissionRequest\x1a\x38.com.digitalasset.canton.domain.api.v0.SendAsyncResponse\x12\x85\x01\n\x0fSendAsyncSigned\x12\x32.com.digitalasset.canton.protocol.v0.SignedContent\x1a>.com.digitalasset.canton.domain.api.v0.SendAsyncSignedResponse\x12\x8c\x01\n\x18SendAsyncUnauthenticated\x12\x36.com.digitalasset.canton.protocol.v0.SubmissionRequest\x1a\x38.com.digitalasset.canton.domain.api.v0.SendAsyncResponse\x12\x96\x01\n\x12SendAsyncVersioned\x12@.com.digitalasset.canton.domain.api.v0.SendAsyncVersionedRequest\x1a>.com.digitalasset.canton.domain.api.v0.SendAsyncSignedResponse\x12\xae\x01\n!SendAsyncUnauthenticatedVersioned\x12O.com.digitalasset.canton.domain.api.v0.SendAsyncUnauthenticatedVersionedRequest\x1a\x38.com.digitalasset.canton.domain.api.v0.SendAsyncResponse\x12\x86\x01\n\tSubscribe\x12:.com.digitalasset.canton.domain.api.v0.SubscriptionRequest\x1a;.com.digitalasset.canton.domain.api.v0.SubscriptionResponse0\x01\x12\x98\x01\n\x12SubscribeVersioned\x12:.com.digitalasset.canton.domain.api.v0.SubscriptionRequest\x1a\x44.com.digitalasset.canton.domain.api.v0.VersionedSubscriptionResponse0\x01\x12\x95\x01\n\x18SubscribeUnauthenticated\x12:.com.digitalasset.canton.domain.api.v0.SubscriptionRequest\x1a;.com.digitalasset.canton.domain.api.v0.SubscriptionResponse0\x01\x12\xa7\x01\n!SubscribeUnauthenticatedVersioned\x12:.com.digitalasset.canton.domain.api.v0.SubscriptionRequest\x1a\x44.com.digitalasset.canton.domain.api.v0.VersionedSubscriptionResponse0\x01\x12`\n\x0b\x41\x63knowledge\x12\x39.com.digitalasset.canton.domain.api.v0.AcknowledgeRequest\x1a\x16.google.protobuf.Empty\x12_\n\x11\x41\x63knowledgeSigned\x12\x32.com.digitalasset.canton.protocol.v0.SignedContent\x1a\x16.google.protobuf.EmptyBVZTgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/api/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.domain.api.v0.sequencer_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZTgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/api/v0'
  _globals['_SENDASYNCVERSIONEDREQUEST']._serialized_start=268
  _globals['_SENDASYNCVERSIONEDREQUEST']._serialized_end=355
  _globals['_SENDASYNCUNAUTHENTICATEDVERSIONEDREQUEST']._serialized_start=357
  _globals['_SENDASYNCUNAUTHENTICATEDVERSIONEDREQUEST']._serialized_end=446
  _globals['_SENDASYNCRESPONSE']._serialized_start=449
  _globals['_SENDASYNCRESPONSE']._serialized_end=859
  _globals['_SENDASYNCRESPONSE_ERROR']._serialized_start=557
  _globals['_SENDASYNCRESPONSE_ERROR']._serialized_end=859
  _globals['_SENDASYNCSIGNEDRESPONSE']._serialized_start=862
  _globals['_SENDASYNCSIGNEDRESPONSE']._serialized_end=1342
  _globals['_SENDASYNCSIGNEDRESPONSE_ERROR']._serialized_start=982
  _globals['_SENDASYNCSIGNEDRESPONSE_ERROR']._serialized_end=1342
  _globals['_SUBSCRIPTIONREQUEST']._serialized_start=1344
  _globals['_SUBSCRIPTIONREQUEST']._serialized_end=1415
  _globals['_SUBSCRIPTIONRESPONSE']._serialized_start=1418
  _globals['_SUBSCRIPTIONRESPONSE']._serialized_end=1625
  _globals['_VERSIONEDSUBSCRIPTIONRESPONSE']._serialized_start=1628
  _globals['_VERSIONEDSUBSCRIPTIONRESPONSE']._serialized_end=1896
  _globals['_ACKNOWLEDGEREQUEST']._serialized_start=1898
  _globals['_ACKNOWLEDGEREQUEST']._serialized_end=2000
  _globals['_SEQUENCEDEVENTTRAFFICSTATE']._serialized_start=2003
  _globals['_SEQUENCEDEVENTTRAFFICSTATE']._serialized_end=2141
  _globals['_SEQUENCERSERVICE']._serialized_start=2144
  _globals['_SEQUENCERSERVICE']._serialized_end=3707
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

"""
Simple command-line handlers.
"""

from __future__ import annotations

import logging
from typing import Sequence

from .._logging import configure as configure_logger
from ._base import CliCommand
from .version import VersionCommand

COMMANDS = list[CliCommand]((VersionCommand(),))


def main():
    """
    Executes one of the known commands.
    """
    from sys import argv, exit

    exit(_main(argv))


def _main(argv: Sequence[str]) -> int:
    if len(argv) > 1:
        command = argv[1]
        command_args = argv[2:]

        for cmd in COMMANDS:
            if cmd.name == command:
                return run(cmd, command_args)

        print("Unknown command: " + command)

    print_cmd_help()
    return -2


def run(cmd, args) -> int:
    parser = cmd.parser()
    parsed_args = parser.parse_args(args)

    log_level = getattr(parsed_args, "log_level", logging.WARNING)
    if log_level is None:
        log_level = logging.WARNING

    configure_logger(level=log_level)
    return cmd.execute(parsed_args)


def print_cmd_help():
    print("Valid commands:")
    for cmd in COMMANDS:
        if not cmd.hidden:
            print(cmd.name)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .pruning_pb2 import ClearSchedule, GetParticipantSchedule, GetSchedule, LocatePruningTimestamp, ParticipantPruningSchedule, PruningSchedule, SetCron, SetMaxDuration, SetParticipantSchedule, SetRetention, SetSchedule

__all__ = [
    "ClearSchedule",
    "GetParticipantSchedule",
    "GetSchedule",
    "LocatePruningTimestamp",
    "ParticipantPruningSchedule",
    "PruningSchedule",
    "SetCron",
    "SetMaxDuration",
    "SetParticipantSchedule",
    "SetRetention",
    "SetSchedule",
]



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/reassignment.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/ledger/api/v2/reassignment.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import event_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_event__pb2
from . import trace_context_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_trace__context__pb2
from . import value_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_value__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)com/daml/ledger/api/v2/reassignment.proto\x12\x16\x63om.daml.ledger.api.v2\x1a\"com/daml/ledger/api/v2/event.proto\x1a*com/daml/ledger/api/v2/trace_context.proto\x1a\"com/daml/ledger/api/v2/value.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xba\x03\n\x0cReassignment\x12\x1b\n\tupdate_id\x18\x01 \x01(\tR\x08updateId\x12\x1d\n\ncommand_id\x18\x02 \x01(\tR\tcommandId\x12\x1f\n\x0bworkflow_id\x18\x03 \x01(\tR\nworkflowId\x12\x16\n\x06offset\x18\x04 \x01(\x03R\x06offset\x12T\n\x10unassigned_event\x18\x05 \x01(\x0b\x32\'.com.daml.ledger.api.v2.UnassignedEventH\x00R\x0funassignedEvent\x12N\n\x0e\x61ssigned_event\x18\x06 \x01(\x0b\x32%.com.daml.ledger.api.v2.AssignedEventH\x00R\rassignedEvent\x12I\n\rtrace_context\x18\x07 \x01(\x0b\x32$.com.daml.ledger.api.v2.TraceContextR\x0ctraceContext\x12;\n\x0brecord_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTimeB\x07\n\x05\x65vent\"\xb8\x03\n\x0fUnassignedEvent\x12\x1f\n\x0bunassign_id\x18\x01 \x01(\tR\nunassignId\x12\x1f\n\x0b\x63ontract_id\x18\x02 \x01(\tR\ncontractId\x12\x43\n\x0btemplate_id\x18\x03 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\ntemplateId\x12\x16\n\x06source\x18\x04 \x01(\tR\x06source\x12\x16\n\x06target\x18\x05 \x01(\tR\x06target\x12\x1c\n\tsubmitter\x18\x06 \x01(\tR\tsubmitter\x12\x31\n\x14reassignment_counter\x18\x07 \x01(\x04R\x13reassignmentCounter\x12Q\n\x16\x61ssignment_exclusivity\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x15\x61ssignmentExclusivity\x12\'\n\x0fwitness_parties\x18\t \x03(\tR\x0ewitnessParties\x12!\n\x0cpackage_name\x18\n \x01(\tR\x0bpackageName\"\xfc\x01\n\rAssignedEvent\x12\x16\n\x06source\x18\x01 \x01(\tR\x06source\x12\x16\n\x06target\x18\x02 \x01(\tR\x06target\x12\x1f\n\x0bunassign_id\x18\x03 \x01(\tR\nunassignId\x12\x1c\n\tsubmitter\x18\x04 \x01(\tR\tsubmitter\x12\x31\n\x14reassignment_counter\x18\x05 \x01(\x04R\x13reassignmentCounter\x12I\n\rcreated_event\x18\x06 \x01(\x0b\x32$.com.daml.ledger.api.v2.CreatedEventR\x0c\x63reatedEventB\x90\x01\n\x16\x63om.daml.ledger.api.v2B\x16ReassignmentOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\xaa\x02\x16\x43om.Daml.Ledger.Api.V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.reassignment_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v2B\026ReassignmentOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\252\002\026Com.Daml.Ledger.Api.V2'
  _globals['_REASSIGNMENT']._serialized_start=219
  _globals['_REASSIGNMENT']._serialized_end=661
  _globals['_UNASSIGNEDEVENT']._serialized_start=664
  _globals['_UNASSIGNEDEVENT']._serialized_end=1104
  _globals['_ASSIGNEDEVENT']._serialized_start=1107
  _globals['_ASSIGNEDEVENT']._serialized_end=1359
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import event_pb2 as _event_pb2
from . import trace_context_pb2 as _trace_context_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TreeEvent(_message.Message):
    __slots__ = ("created", "exercised")
    CREATED_FIELD_NUMBER: _ClassVar[int]
    EXERCISED_FIELD_NUMBER: _ClassVar[int]
    created: _event_pb2.CreatedEvent
    exercised: _event_pb2.ExercisedEvent
    def __init__(self, created: _Optional[_Union[_event_pb2.CreatedEvent, _Mapping]] = ..., exercised: _Optional[_Union[_event_pb2.ExercisedEvent, _Mapping]] = ...) -> None: ...

class TransactionTree(_message.Message):
    __slots__ = ("update_id", "command_id", "workflow_id", "effective_at", "offset", "events_by_id", "root_event_ids", "domain_id", "trace_context", "record_time")
    class EventsByIdEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: TreeEvent
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[TreeEvent, _Mapping]] = ...) -> None: ...
    UPDATE_ID_FIELD_NUMBER: _ClassVar[int]
    COMMAND_ID_FIELD_NUMBER: _ClassVar[int]
    WORKFLOW_ID_FIELD_NUMBER: _ClassVar[int]
    EFFECTIVE_AT_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    EVENTS_BY_ID_FIELD_NUMBER: _ClassVar[int]
    ROOT_EVENT_IDS_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    TRACE_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    RECORD_TIME_FIELD_NUMBER: _ClassVar[int]
    update_id: str
    command_id: str
    workflow_id: str
    effective_at: _timestamp_pb2.Timestamp
    offset: int
    events_by_id: _containers.MessageMap[str, TreeEvent]
    root_event_ids: _containers.RepeatedScalarFieldContainer[str]
    domain_id: str
    trace_context: _trace_context_pb2.TraceContext
    record_time: _timestamp_pb2.Timestamp
    def __init__(self, update_id: _Optional[str] = ..., command_id: _Optional[str] = ..., workflow_id: _Optional[str] = ..., effective_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., offset: _Optional[int] = ..., events_by_id: _Optional[_Mapping[str, TreeEvent]] = ..., root_event_ids: _Optional[_Iterable[str]] = ..., domain_id: _Optional[str] = ..., trace_context: _Optional[_Union[_trace_context_pb2.TraceContext, _Mapping]] = ..., record_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class Transaction(_message.Message):
    __slots__ = ("update_id", "command_id", "workflow_id", "effective_at", "events", "offset", "domain_id", "trace_context", "record_time")
    UPDATE_ID_FIELD_NUMBER: _ClassVar[int]
    COMMAND_ID_FIELD_NUMBER: _ClassVar[int]
    WORKFLOW_ID_FIELD_NUMBER: _ClassVar[int]
    EFFECTIVE_AT_FIELD_NUMBER: _ClassVar[int]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    TRACE_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    RECORD_TIME_FIELD_NUMBER: _ClassVar[int]
    update_id: str
    command_id: str
    workflow_id: str
    effective_at: _timestamp_pb2.Timestamp
    events: _containers.RepeatedCompositeFieldContainer[_event_pb2.Event]
    offset: int
    domain_id: str
    trace_context: _trace_context_pb2.TraceContext
    record_time: _timestamp_pb2.Timestamp
    def __init__(self, update_id: _Optional[str] = ..., command_id: _Optional[str] = ..., workflow_id: _Optional[str] = ..., effective_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., events: _Optional[_Iterable[_Union[_event_pb2.Event, _Mapping]]] = ..., offset: _Optional[int] = ..., domain_id: _Optional[str] = ..., trace_context: _Optional[_Union[_trace_context_pb2.TraceContext, _Mapping]] = ..., record_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v30/acs_commitments.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v30/acs_commitments.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:com/digitalasset/canton/protocol/v30/acs_commitments.proto\x12$com.digitalasset.canton.protocol.v30\"\x86\x02\n\rAcsCommitment\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\x12\x36\n\x17sending_participant_uid\x18\x02 \x01(\tR\x15sendingParticipantUid\x12\x36\n\x17\x63ounter_participant_uid\x18\x03 \x01(\tR\x15\x63ounterParticipantUid\x12%\n\x0e\x66rom_exclusive\x18\x04 \x01(\x03R\rfromExclusive\x12!\n\x0cto_inclusive\x18\x05 \x01(\x03R\x0btoInclusive\x12\x1e\n\ncommitment\x18\x06 \x01(\x0cR\ncommitmentBUZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v30.acs_commitments_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30'
  _globals['_ACSCOMMITMENT']._serialized_start=101
  _globals['_ACSCOMMITMENT']._serialized_end=363
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PeerEndpointHealthStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    PEER_ENDPOINT_HEALTH_STATUS_UNSPECIFIED: _ClassVar[PeerEndpointHealthStatus]
    PEER_ENDPOINT_HEALTH_STATUS_UNKNOWN_ENDPOINT: _ClassVar[PeerEndpointHealthStatus]
    PEER_ENDPOINT_HEALTH_STATUS_UNAUTHENTICATED: _ClassVar[PeerEndpointHealthStatus]
    PEER_ENDPOINT_HEALTH_STATUS_AUTHENTICATED: _ClassVar[PeerEndpointHealthStatus]
PEER_ENDPOINT_HEALTH_STATUS_UNSPECIFIED: PeerEndpointHealthStatus
PEER_ENDPOINT_HEALTH_STATUS_UNKNOWN_ENDPOINT: PeerEndpointHealthStatus
PEER_ENDPOINT_HEALTH_STATUS_UNAUTHENTICATED: PeerEndpointHealthStatus
PEER_ENDPOINT_HEALTH_STATUS_AUTHENTICATED: PeerEndpointHealthStatus

class AddPeerEndpointRequest(_message.Message):
    __slots__ = ("endpoint",)
    ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    endpoint: PeerEndpoint
    def __init__(self, endpoint: _Optional[_Union[PeerEndpoint, _Mapping]] = ...) -> None: ...

class RemovePeerEndpointRequest(_message.Message):
    __slots__ = ("endpoint",)
    ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    endpoint: PeerEndpoint
    def __init__(self, endpoint: _Optional[_Union[PeerEndpoint, _Mapping]] = ...) -> None: ...

class PeerEndpoint(_message.Message):
    __slots__ = ("host", "port")
    HOST_FIELD_NUMBER: _ClassVar[int]
    PORT_FIELD_NUMBER: _ClassVar[int]
    host: str
    port: int
    def __init__(self, host: _Optional[str] = ..., port: _Optional[int] = ...) -> None: ...

class AddPeerEndpointResponse(_message.Message):
    __slots__ = ("added",)
    ADDED_FIELD_NUMBER: _ClassVar[int]
    added: bool
    def __init__(self, added: bool = ...) -> None: ...

class RemovePeerEndpointResponse(_message.Message):
    __slots__ = ("removed",)
    REMOVED_FIELD_NUMBER: _ClassVar[int]
    removed: bool
    def __init__(self, removed: bool = ...) -> None: ...

class PeerEndpointHealth(_message.Message):
    __slots__ = ("status", "description")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    status: PeerEndpointHealthStatus
    description: _wrappers_pb2.StringValue
    def __init__(self, status: _Optional[_Union[PeerEndpointHealthStatus, str]] = ..., description: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...

class PeerEndpointStatus(_message.Message):
    __slots__ = ("endpoint", "health")
    ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    HEALTH_FIELD_NUMBER: _ClassVar[int]
    endpoint: PeerEndpoint
    health: PeerEndpointHealth
    def __init__(self, endpoint: _Optional[_Union[PeerEndpoint, _Mapping]] = ..., health: _Optional[_Union[PeerEndpointHealth, _Mapping]] = ...) -> None: ...

class GetPeerNetworkStatusRequest(_message.Message):
    __slots__ = ("endpoints",)
    ENDPOINTS_FIELD_NUMBER: _ClassVar[int]
    endpoints: _containers.RepeatedCompositeFieldContainer[PeerEndpoint]
    def __init__(self, endpoints: _Optional[_Iterable[_Union[PeerEndpoint, _Mapping]]] = ...) -> None: ...

class GetPeerNetworkStatusResponse(_message.Message):
    __slots__ = ("statuses",)
    STATUSES_FIELD_NUMBER: _ClassVar[int]
    statuses: _containers.RepeatedCompositeFieldContainer[PeerEndpointStatus]
    def __init__(self, statuses: _Optional[_Iterable[_Union[PeerEndpointStatus, _Mapping]]] = ...) -> None: ...

class GetOrderingTopologyRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetOrderingTopologyResponse(_message.Message):
    __slots__ = ("current_epoch", "sequencer_ids")
    CURRENT_EPOCH_FIELD_NUMBER: _ClassVar[int]
    SEQUENCER_IDS_FIELD_NUMBER: _ClassVar[int]
    current_epoch: int
    sequencer_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, current_epoch: _Optional[int] = ..., sequencer_ids: _Optional[_Iterable[str]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/domain/api/v30/sequencer_authentication_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/domain/api/v30/sequencer_authentication_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....crypto.v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMcom/digitalasset/canton/domain/api/v30/sequencer_authentication_service.proto\x12&com.digitalasset.canton.domain.api.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xeb\x08\n\x17SequencerAuthentication\x1a\x64\n\x10\x43hallengeRequest\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12\x38\n\x18member_protocol_versions\x18\x02 \x03(\tR\x16memberProtocolVersions\x1a\xad\x03\n\x11\x43hallengeResponse\x12u\n\x07success\x18\x01 \x01(\x0b\x32Y.com.digitalasset.canton.domain.api.v30.SequencerAuthentication.ChallengeResponse.SuccessH\x00R\x07success\x12u\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32Y.com.digitalasset.canton.domain.api.v30.SequencerAuthentication.ChallengeResponse.FailureH\x00R\x07\x66\x61ilure\x1aj\n\x07Success\x12%\n\x0e\x64omain_version\x18\x01 \x01(\tR\rdomainVersion\x12\x14\n\x05nonce\x18\x02 \x01(\x0cR\x05nonce\x12\"\n\x0c\x66ingerprints\x18\x03 \x03(\tR\x0c\x66ingerprints\x1a\x35\n\x07\x46\x61ilure\x12\x12\n\x04\x63ode\x18\x01 \x01(\rR\x04\x63ode\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reasonB\x07\n\x05value\x1a\x90\x01\n\x13\x41uthenticateRequest\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12K\n\tsignature\x18\x02 \x01(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\tsignature\x12\x14\n\x05nonce\x18\x03 \x01(\x0cR\x05nonce\x1a\xa6\x03\n\x14\x41uthenticateResponse\x12x\n\x07success\x18\x01 \x01(\x0b\x32\\.com.digitalasset.canton.domain.api.v30.SequencerAuthentication.AuthenticateResponse.SuccessH\x00R\x07success\x12x\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32\\.com.digitalasset.canton.domain.api.v30.SequencerAuthentication.AuthenticateResponse.FailureH\x00R\x07\x66\x61ilure\x1aZ\n\x07Success\x12\x14\n\x05token\x18\x01 \x01(\x0cR\x05token\x12\x39\n\nexpires_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\x1a\x35\n\x07\x46\x61ilure\x12\x12\n\x04\x63ode\x18\x01 \x01(\rR\x04\x63ode\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reasonB\x07\n\x05value2\x93\x03\n\x1eSequencerAuthenticationService\x12\xb2\x01\n\tChallenge\x12P.com.digitalasset.canton.domain.api.v30.SequencerAuthentication.ChallengeRequest\x1aQ.com.digitalasset.canton.domain.api.v30.SequencerAuthentication.ChallengeResponse\"\x00\x12\xbb\x01\n\x0c\x41uthenticate\x12S.com.digitalasset.canton.domain.api.v30.SequencerAuthentication.AuthenticateRequest\x1aT.com.digitalasset.canton.domain.api.v30.SequencerAuthentication.AuthenticateResponse\"\x00\x42WZUgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/api/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.domain.api.v30.sequencer_authentication_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZUgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/api/v30'
  _globals['_SEQUENCERAUTHENTICATION']._serialized_start=204
  _globals['_SEQUENCERAUTHENTICATION']._serialized_end=1335
  _globals['_SEQUENCERAUTHENTICATION_CHALLENGEREQUEST']._serialized_start=231
  _globals['_SEQUENCERAUTHENTICATION_CHALLENGEREQUEST']._serialized_end=331
  _globals['_SEQUENCERAUTHENTICATION_CHALLENGERESPONSE']._serialized_start=334
  _globals['_SEQUENCERAUTHENTICATION_CHALLENGERESPONSE']._serialized_end=763
  _globals['_SEQUENCERAUTHENTICATION_CHALLENGERESPONSE_SUCCESS']._serialized_start=593
  _globals['_SEQUENCERAUTHENTICATION_CHALLENGERESPONSE_SUCCESS']._serialized_end=699
  _globals['_SEQUENCERAUTHENTICATION_CHALLENGERESPONSE_FAILURE']._serialized_start=701
  _globals['_SEQUENCERAUTHENTICATION_CHALLENGERESPONSE_FAILURE']._serialized_end=754
  _globals['_SEQUENCERAUTHENTICATION_AUTHENTICATEREQUEST']._serialized_start=766
  _globals['_SEQUENCERAUTHENTICATION_AUTHENTICATEREQUEST']._serialized_end=910
  _globals['_SEQUENCERAUTHENTICATION_AUTHENTICATERESPONSE']._serialized_start=913
  _globals['_SEQUENCERAUTHENTICATION_AUTHENTICATERESPONSE']._serialized_end=1335
  _globals['_SEQUENCERAUTHENTICATION_AUTHENTICATERESPONSE_SUCCESS']._serialized_start=1181
  _globals['_SEQUENCERAUTHENTICATION_AUTHENTICATERESPONSE_SUCCESS']._serialized_end=1271
  _globals['_SEQUENCERAUTHENTICATION_AUTHENTICATERESPONSE_FAILURE']._serialized_start=701
  _globals['_SEQUENCERAUTHENTICATION_AUTHENTICATERESPONSE_FAILURE']._serialized_end=754
  _globals['_SEQUENCERAUTHENTICATIONSERVICE']._serialized_start=1338
  _globals['_SEQUENCERAUTHENTICATIONSERVICE']._serialized_end=1741
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/enterprise_participant_replication_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/admin/participant/v30/enterprise_participant_replication_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n^com/digitalasset/canton/admin/participant/v30/enterprise_participant_replication_service.proto\x12-com.digitalasset.canton.admin.participant.v30\"J\n\nSetPassive\x1a\t\n\x07Request\x1a\x31\n\x08Response\x12%\n\x0e\x62\x65\x63\x61me_passive\x18\x01 \x01(\x08R\rbecamePassive2\xbf\x01\n\'EnterpriseParticipantReplicationService\x12\x93\x01\n\nSetPassive\x12\x41.com.digitalasset.canton.admin.participant.v30.SetPassive.Request\x1a\x42.com.digitalasset.canton.admin.participant.v30.SetPassive.ResponseB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.enterprise_participant_replication_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_SETPASSIVE']._serialized_start=145
  _globals['_SETPASSIVE']._serialized_end=219
  _globals['_SETPASSIVE_REQUEST']._serialized_start=159
  _globals['_SETPASSIVE_REQUEST']._serialized_end=168
  _globals['_SETPASSIVE_RESPONSE']._serialized_start=170
  _globals['_SETPASSIVE_RESPONSE']._serialized_end=219
  _globals['_ENTERPRISEPARTICIPANTREPLICATIONSERVICE']._serialized_start=222
  _globals['_ENTERPRISEPARTICIPANTREPLICATIONSERVICE']._serialized_end=413
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .vault_service_pb2 import DeleteKeyPairRequest, DeleteKeyPairResponse, ExportKeyPairRequest, ExportKeyPairResponse, GenerateCertificateRequest, GenerateCertificateResponse, GenerateEncryptionKeyRequest, GenerateEncryptionKeyResponse, GenerateSigningKeyRequest, GenerateSigningKeyResponse, GetWrapperKeyIdRequest, GetWrapperKeyIdResponse, ImportCertificateRequest, ImportCertificateResponse, ImportKeyPairRequest, ImportKeyPairResponse, ImportPublicKeyRequest, ImportPublicKeyResponse, ListCertificateRequest, ListCertificateResponse, ListKeysRequest, ListKeysResponse, ListMyKeysResponse, PrivateKeyMetadata, RegisterKmsEncryptionKeyRequest, RegisterKmsEncryptionKeyResponse, RegisterKmsSigningKeyRequest, RegisterKmsSigningKeyResponse, RotateWrapperKeyRequest
from .vault_service_pb2_grpc import VaultServiceStub

__all__ = [
    "DeleteKeyPairRequest",
    "DeleteKeyPairResponse",
    "ExportKeyPairRequest",
    "ExportKeyPairResponse",
    "GenerateCertificateRequest",
    "GenerateCertificateResponse",
    "GenerateEncryptionKeyRequest",
    "GenerateEncryptionKeyResponse",
    "GenerateSigningKeyRequest",
    "GenerateSigningKeyResponse",
    "GetWrapperKeyIdRequest",
    "GetWrapperKeyIdResponse",
    "ImportCertificateRequest",
    "ImportCertificateResponse",
    "ImportKeyPairRequest",
    "ImportKeyPairResponse",
    "ImportPublicKeyRequest",
    "ImportPublicKeyResponse",
    "ListCertificateRequest",
    "ListCertificateResponse",
    "ListKeysRequest",
    "ListKeysResponse",
    "ListMyKeysResponse",
    "PrivateKeyMetadata",
    "RegisterKmsEncryptionKeyRequest",
    "RegisterKmsEncryptionKeyResponse",
    "RegisterKmsSigningKeyRequest",
    "RegisterKmsSigningKeyResponse",
    "RotateWrapperKeyRequest",
    "VaultServiceStub",
]



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

import os
from os import PathLike
from pathlib import Path
import shutil
from tempfile import TemporaryDirectory
from typing import Collection, Optional

from google.protobuf.compiler.plugin_pb2 import CodeGeneratorRequest, CodeGeneratorResponse, Version
from google.protobuf.descriptor_pb2 import FileDescriptorSet
import grpc_tools.protoc
from rich.console import Console

__all__ = ["run", "request", "write_response"]


def run(
    fds_file: PathLike, plugins: Collection[str], options: Collection[str] = ()
) -> CodeGeneratorResponse:
    """
    Run the Protobuf compiler on built-in plugins.
    """
    fds = FileDescriptorSet()
    fds.ParseFromString(Path(fds_file).read_bytes())
    filelist = [
        f.name
        for f in fds.file
        if f.name.startswith("com/daml") or f.name.startswith("com/digitalasset")
    ]

    import site

    include_dirs = []
    include_dirs.extend(site.getsitepackages())
    include_dirs.append(grpc_tools.protoc._get_resource_file_name("grpc_tools", "_proto"))

    fds_path = Path(fds_file)
    with TemporaryDirectory() as tmpdir:
        tmpdir_path = Path(tmpdir)
        args = [
            "grpc_tools.protoc",
            f"--descriptor_set_in={fds_path}",
            *(f"-I{include}" for include in include_dirs),
            *(f"--{plugin}_out={tmpdir}" for plugin in plugins),
            *options,
            *filelist,
        ]

        grpc_tools.protoc.main(args)

        return CodeGeneratorResponse(
            file=[
                CodeGeneratorResponse.File(
                    name=str(f.relative_to(tmpdir_path)), content=f.read_text()
                )
                for f in tmpdir_path.glob("**/*")
                if f.is_file()
            ]
        )


def generate_descriptors(root_dir: Path, to: Path) -> None:
    console = Console()
    cwd = os.getcwd()
    os.chdir(root_dir)

    proto_files = []
    for s in root_dir.glob("**/*.proto"):
        proto_files.append(str(s.relative_to(root_dir)))
    proto_files.sort()

    include_dirs = []
    import site

    include_dirs.extend(site.getsitepackages())
    include_dirs.append(grpc_tools.protoc._get_resource_file_name("grpc_tools", "_proto"))
    include_dirs.append(str(root_dir))

    try:
        args = [
            "grpc_tools.protoc",
            f"--descriptor_set_out={to}",
            *(f"-I{include}" for include in include_dirs),
            *proto_files,
        ]
        console.print("Calling " + " ".join(args))
        grpc_tools.protoc.main(args)
    finally:
        os.chdir(cwd)


def request(fds_file: PathLike, parameter: Optional[str] = None) -> CodeGeneratorRequest:
    b = Path(fds_file).read_bytes()

    fds = FileDescriptorSet()
    fds.ParseFromString(b)

    request = CodeGeneratorRequest(
        file_to_generate=[f.name for f in fds.file if f.name.startswith("com/")],
        parameter=parameter,
        proto_file=fds.file,
        compiler_version=Version(),
    )

    with TemporaryDirectory() as tmpdir:
        grpc_tools.protoc.main()

    if parameter is not None:
        request.parameter = parameter
    return request


def write_response(response: CodeGeneratorResponse, output_dir: Path) -> None:
    """
    Write the files indicated in ``response`` to the specified output directory. If the directory
    does not exist, it is created. If the specified path has files, it is cleared first.
    """
    shutil.rmtree(output_dir)
    output_dir.mkdir(parents=True, exist_ok=True)
    for f in response.file:
        output_file = output_dir / f.name
        output_file.parent.mkdir(parents=True, exist_ok=True)
        output_file.write_text(f.content)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/participant_repair_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/admin/participant/v30/participant_repair_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import domain_connectivity_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_domain__connectivity__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNcom/digitalasset/canton/admin/participant/v30/participant_repair_service.proto\x12-com.digitalasset.canton.admin.participant.v30\x1aGcom/digitalasset/canton/admin/participant/v30/domain_connectivity.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x86\x01\n\x15PurgeContractsRequest\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12!\n\x0c\x63ontract_ids\x18\x02 \x03(\tR\x0b\x63ontractIds\x12\x32\n\x15ignore_already_purged\x18\x03 \x01(\x08R\x13ignoreAlreadyPurged\"\x18\n\x16PurgeContractsResponse\"\xde\x01\n\x14MigrateDomainRequest\x12!\n\x0csource_alias\x18\x01 \x01(\tR\x0bsourceAlias\x12\x8c\x01\n\x1ftarget_domain_connection_config\x18\x02 \x01(\x0b\x32\x45.com.digitalasset.canton.admin.participant.v30.DomainConnectionConfigR\x1ctargetDomainConnectionConfig\x12\x14\n\x05\x66orce\x18\x03 \x01(\x08R\x05\x66orce\"\x17\n\x15MigrateDomainResponse\"\xdd\x04\n\x10\x45xportAcsRequest\x12\x18\n\x07parties\x18\x01 \x03(\tR\x07parties\x12(\n\x10\x66ilter_domain_id\x18\x02 \x01(\tR\x0e\x66ilterDomainId\x12\x38\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x92\x01\n\x17\x63ontract_domain_renames\x18\x04 \x03(\x0b\x32Z.com.digitalasset.canton.admin.participant.v30.ExportAcsRequest.ContractDomainRenamesEntryR\x15\x63ontractDomainRenames\x12\x14\n\x05\x66orce\x18\x05 \x01(\x08R\x05\x66orce\x12/\n\x13parties_offboarding\x18\x06 \x01(\x08R\x12partiesOffboarding\x1aV\n\x0cTargetDomain\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\x12)\n\x10protocol_version\x18\x02 \x01(\x05R\x0fprotocolVersion\x1a\x96\x01\n\x1a\x43ontractDomainRenamesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x62\n\x05value\x18\x02 \x01(\x0b\x32L.com.digitalasset.canton.admin.participant.v30.ExportAcsRequest.TargetDomainR\x05value:\x02\x38\x01\")\n\x11\x45xportAcsResponse\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk\"\xb7\x01\n\x10ImportAcsRequest\x12!\n\x0c\x61\x63s_snapshot\x18\x01 \x01(\x0cR\x0b\x61\x63sSnapshot\x12,\n\x12workflow_id_prefix\x18\x02 \x01(\tR\x10workflowIdPrefix\x12R\n&allow_contract_id_suffix_recomputation\x18\x03 \x01(\x08R\"allowContractIdSuffixRecomputation\"\xe3\x01\n\x11ImportAcsResponse\x12\x87\x01\n\x13\x63ontract_id_mapping\x18\x01 \x03(\x0b\x32W.com.digitalasset.canton.admin.participant.v30.ImportAcsResponse.ContractIdMappingEntryR\x11\x63ontractIdMapping\x1a\x44\n\x16\x43ontractIdMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"B\n\x1dPurgeDeactivatedDomainRequest\x12!\n\x0c\x64omain_alias\x18\x01 \x01(\tR\x0b\x64omainAlias\" \n\x1ePurgeDeactivatedDomainResponse\"\x92\x01\n\x13IgnoreEventsRequest\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\x12%\n\x0e\x66rom_inclusive\x18\x02 \x01(\x03R\rfromInclusive\x12!\n\x0cto_inclusive\x18\x03 \x01(\x03R\x0btoInclusive\x12\x14\n\x05\x66orce\x18\x04 \x01(\x08R\x05\x66orce\"\x16\n\x14IgnoreEventsResponse\"\x94\x01\n\x15UnignoreEventsRequest\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\x12%\n\x0e\x66rom_inclusive\x18\x02 \x01(\x03R\rfromInclusive\x12!\n\x0cto_inclusive\x18\x03 \x01(\x03R\x0btoInclusive\x12\x14\n\x05\x66orce\x18\x04 \x01(\x08R\x05\x66orce\"\x18\n\x16UnignoreEventsResponse2\xef\x08\n\x18ParticipantRepairService\x12\x90\x01\n\tExportAcs\x12?.com.digitalasset.canton.admin.participant.v30.ExportAcsRequest\x1a@.com.digitalasset.canton.admin.participant.v30.ExportAcsResponse0\x01\x12\x90\x01\n\tImportAcs\x12?.com.digitalasset.canton.admin.participant.v30.ImportAcsRequest\x1a@.com.digitalasset.canton.admin.participant.v30.ImportAcsResponse(\x01\x12\x9d\x01\n\x0ePurgeContracts\x12\x44.com.digitalasset.canton.admin.participant.v30.PurgeContractsRequest\x1a\x45.com.digitalasset.canton.admin.participant.v30.PurgeContractsResponse\x12\x9a\x01\n\rMigrateDomain\x12\x43.com.digitalasset.canton.admin.participant.v30.MigrateDomainRequest\x1a\x44.com.digitalasset.canton.admin.participant.v30.MigrateDomainResponse\x12\xb5\x01\n\x16PurgeDeactivatedDomain\x12L.com.digitalasset.canton.admin.participant.v30.PurgeDeactivatedDomainRequest\x1aM.com.digitalasset.canton.admin.participant.v30.PurgeDeactivatedDomainResponse\x12\x97\x01\n\x0cIgnoreEvents\x12\x42.com.digitalasset.canton.admin.participant.v30.IgnoreEventsRequest\x1a\x43.com.digitalasset.canton.admin.participant.v30.IgnoreEventsResponse\x12\x9d\x01\n\x0eUnignoreEvents\x12\x44.com.digitalasset.canton.admin.participant.v30.UnignoreEventsRequest\x1a\x45.com.digitalasset.canton.admin.participant.v30.UnignoreEventsResponseB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.participant_repair_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_EXPORTACSREQUEST_CONTRACTDOMAINRENAMESENTRY']._loaded_options = None
  _globals['_EXPORTACSREQUEST_CONTRACTDOMAINRENAMESENTRY']._serialized_options = b'8\001'
  _globals['_IMPORTACSRESPONSE_CONTRACTIDMAPPINGENTRY']._loaded_options = None
  _globals['_IMPORTACSRESPONSE_CONTRACTIDMAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_PURGECONTRACTSREQUEST']._serialized_start=236
  _globals['_PURGECONTRACTSREQUEST']._serialized_end=370
  _globals['_PURGECONTRACTSRESPONSE']._serialized_start=372
  _globals['_PURGECONTRACTSRESPONSE']._serialized_end=396
  _globals['_MIGRATEDOMAINREQUEST']._serialized_start=399
  _globals['_MIGRATEDOMAINREQUEST']._serialized_end=621
  _globals['_MIGRATEDOMAINRESPONSE']._serialized_start=623
  _globals['_MIGRATEDOMAINRESPONSE']._serialized_end=646
  _globals['_EXPORTACSREQUEST']._serialized_start=649
  _globals['_EXPORTACSREQUEST']._serialized_end=1254
  _globals['_EXPORTACSREQUEST_TARGETDOMAIN']._serialized_start=1015
  _globals['_EXPORTACSREQUEST_TARGETDOMAIN']._serialized_end=1101
  _globals['_EXPORTACSREQUEST_CONTRACTDOMAINRENAMESENTRY']._serialized_start=1104
  _globals['_EXPORTACSREQUEST_CONTRACTDOMAINRENAMESENTRY']._serialized_end=1254
  _globals['_EXPORTACSRESPONSE']._serialized_start=1256
  _globals['_EXPORTACSRESPONSE']._serialized_end=1297
  _globals['_IMPORTACSREQUEST']._serialized_start=1300
  _globals['_IMPORTACSREQUEST']._serialized_end=1483
  _globals['_IMPORTACSRESPONSE']._serialized_start=1486
  _globals['_IMPORTACSRESPONSE']._serialized_end=1713
  _globals['_IMPORTACSRESPONSE_CONTRACTIDMAPPINGENTRY']._serialized_start=1645
  _globals['_IMPORTACSRESPONSE_CONTRACTIDMAPPINGENTRY']._serialized_end=1713
  _globals['_PURGEDEACTIVATEDDOMAINREQUEST']._serialized_start=1715
  _globals['_PURGEDEACTIVATEDDOMAINREQUEST']._serialized_end=1781
  _globals['_PURGEDEACTIVATEDDOMAINRESPONSE']._serialized_start=1783
  _globals['_PURGEDEACTIVATEDDOMAINRESPONSE']._serialized_end=1815
  _globals['_IGNOREEVENTSREQUEST']._serialized_start=1818
  _globals['_IGNOREEVENTSREQUEST']._serialized_end=1964
  _globals['_IGNOREEVENTSRESPONSE']._serialized_start=1966
  _globals['_IGNOREEVENTSRESPONSE']._serialized_end=1988
  _globals['_UNIGNOREEVENTSREQUEST']._serialized_start=1991
  _globals['_UNIGNOREEVENTSREQUEST']._serialized_end=2139
  _globals['_UNIGNOREEVENTSRESPONSE']._serialized_start=2141
  _globals['_UNIGNOREEVENTSRESPONSE']._serialized_end=2165
  _globals['_PARTICIPANTREPAIRSERVICE']._serialized_start=2168
  _globals['_PARTICIPANTREPAIRSERVICE']._serialized_end=3303
# @@protoc_insertion_point(module_scope)
